@@ -18,12 +18,12 @@ from tsfresh.utilities.dataframe_functions import make_forecasting_frame
 from tsfresh.utilities.dataframe_functions import impute
 
 
-def buildAdvancedPriceFeatures(quotes_df=None, max_timeshift=20, rolling_direction=1):
+def buildAdvancedPriceFeatures(quotes_df=None, lookback_window=20, rolling_direction=1):
     strats = [col for col in quotes_df.columns if col != 'Date' ]
     aggregated_features = None
     for strat in strats:
         print('processing '+strat)
-        df_shift, y = make_forecasting_frame(quotes_df[strat], kind="price", max_timeshift=20, rolling_direction=1)
+        df_shift, y = make_forecasting_frame(quotes_df[strat], kind="price", max_timeshift=lookback_window, rolling_direction=1)
         X = extract_features(df_shift, column_id="id", column_sort="time", column_value="value", impute_function=impute, show_warnings=False)
         X = X.loc[:, X.apply(pd.Series.nunique) != 1]
         X.columns = [strat + col for col in X.columns]
@@ -36,7 +36,7 @@ def buildAdvancedPriceFeatures(quotes_df=None, max_timeshift=20, rolling_directi
 
 
 class AbstractAssembler(ABC):
-    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro',max_timeshift=20, rolling_direction=1):
+    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', ts_features_pkl_file_name='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
         super().__init__()
         self.local_root_directory = local_root_directory
         self.user = user
@@ -48,16 +48,16 @@ class AbstractAssembler(ABC):
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
         self.running_date=running_date
         self.starting_date=starting_date
-        self.max_timeshift = max_timeshift
         self.rolling_direction = rolling_direction
+        self.ts_features_pkl_file_name=ts_features_pkl_file_name
 
     @abstractmethod
-    def assembleFeature(self, feature_type, n_past_features):
+    def assembleFeature(self, feature_type, n_past_features, tsfresh_lookback_window):
         pass
 
 
 class FeaturesAssembler(AbstractAssembler):
-    def reassembleAdvancedFeaturesForClusterization(self, feature_type, n_past_features = 21, simple = True):
+    def reassembleAdvancedFeaturesForClusterization(self, feature_type, n_past_features, tsfresh_lookback_window, simple = True):
         if (feature_type is features_type.FeaturesType.HISTORY or feature_type is features_type.FeaturesType.HISTORY_ADVANCED) and n_past_features is None:
             return
         if (feature_type is features_type.FeaturesType.STANDARD or feature_type is features_type.FeaturesType.STANDARD_ADVANCED) and n_past_features is not None:
@@ -70,7 +70,7 @@ class FeaturesAssembler(AbstractAssembler):
         torch.manual_seed(0)
 
         advanced_features, advanced_features_names = self.preprocessFeatures()
-        df, strats, strat_features_names = self.preprocessReturns()
+        df, strats, strat_features_names = self.preprocessReturns(tsfresh_lookback_window)
 
 
         features_names = [col for col in list(advanced_features.columns) if col != 'Date']
@@ -263,7 +263,7 @@ class FeaturesAssembler(AbstractAssembler):
 
         return features , features_names
 
-    def preprocessReturns(self):
+    def preprocessReturns(self, lookback_window, ts_fresh_indices = ['SPXT'], add_signal_predictor = False):
 
         df = self.dbx.local_overwrite_and_load_pickle( folder='', subfolder='', returns_pkl_file_name=self.returns_pkl_file_name, local_root_directory = self.local_root_directory)
         df['Date'] = pd.to_datetime(df['Date'])
@@ -271,7 +271,18 @@ class FeaturesAssembler(AbstractAssembler):
         df = df.set_index('Date')
         df = df.fillna(method='ffill').fillna(method='bfill')
 
-        advanced_ts_features = buildAdvancedPriceFeatures(quotes_df=df[strats],max_timeshift=self.max_timeshift, rolling_direction=self.rolling_direction)
+        if add_signal_predictor:
+            advanced_signals_ts_features = buildAdvancedPriceFeatures(quotes_df=df[strats], lookback_window=lookback_window,rolling_direction=self.rolling_direction)
+
+        ts_features = self.dbx.local_overwrite_and_load_pickle( folder='', subfolder=self.macro_features_directory, returns_pkl_file_name=self.ts_features_pkl_file_name, local_root_directory = Path(self.local_root_directory))
+        ts_features_names = [col for col in list(ts_features.columns) if col!='Date']
+        ts_features['Date'] = pd.to_datetime(ts_features['Date'])
+        ts_features = ts_features.set_index('Date')
+        ts_features=ts_features.astype('float64')
+
+        advanced_ts_features = buildAdvancedPriceFeatures(quotes_df=ts_features[ts_fresh_indices],lookback_window=lookback_window, rolling_direction=self.rolling_direction)
+        print('Advanced ts fresh features size')
+        print(ts_features.shape)
 
         df = pd.merge(df, advanced_ts_features, how='left', left_index=True, right_index=True)
 
@@ -380,7 +391,8 @@ class FeaturesAssembler(AbstractAssembler):
         return df , strats, strat_features
 
 
-    def assembleFeature(self, feature_type, n_past_features):
+    def assembleFeature(self, feature_type, n_past_features, tsfresh_lookback_window):
+
 
         if (feature_type is features_type.FeaturesType.HISTORY or feature_type is features_type.FeaturesType.HISTORY_ADVANCED) and n_past_features is None:
             return
@@ -397,7 +409,7 @@ class FeaturesAssembler(AbstractAssembler):
 
         advanced_features, advanced_features_names = self.preprocessFeatures()
 
-        df_ret, strats, strat_features_names = self.preprocessReturns()
+        df_ret, strats, strat_features_names = self.preprocessReturns(tsfresh_lookback_window)
         features_names = [col for col in list(advanced_features.columns) if col!='Date']
 
         max_date = max(advanced_features['Date'])
