@@ -9,15 +9,16 @@ from napoleontoolbox.file_saver import dropbox_file_saver
 import json
 
 class SignalParalleLauncher():
-    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', signal_idiosyncratic_paramaters=[None]):
+    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', triggers = [True], signal_idiosyncratic_paramaters=[None]):
         self.args = []
         self.counter = 1
         self.seed = 0
-        for signal_type, params  in signal_idiosyncratic_paramaters.items():
-            for param in params:
-                self.args.append((self,self.seed,signal_type,json.dumps(param, sort_keys=True)))
-                self.counter = self.counter + 1
-        self.args.sort()
+        for trigger in triggers:
+            for signal_type, params  in signal_idiosyncratic_paramaters.items():
+                for param in params:
+                    self.args.append((self,self.seed,trigger,signal_type,json.dumps(param, sort_keys=True)))
+                    self.counter = self.counter + 1
+            self.args.sort()
         self.local_root_directory = local_root_directory
         self.user = user
         self.db_path_suffix = db_path_suffix
