@@ -14,7 +14,7 @@ import json
 
 
 def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4):
-    data['turn_over'] = abs(data['signal'] - data['signal_gen']) / 2.
+    data['turn_over'] = abs(data['signal'] - data['signal'].shift(-1).fillna(0.))
     print('average hourly turn over')
     print(data['turn_over'].sum() / len(data))
     data['close_return'] = data['close'].pct_change()
@@ -89,6 +89,15 @@ class SimpleSignalRunner(AbstractRunner):
         #kwargs = {**generics, **idios}
         signal_generation_method_to_call = getattr(signal_generator, signal_type)
         hourly_df = pd.read_pickle(self.local_root_directory+self.hourly_pkl_file_name)
+        print('time range before filtering ')
+        print(max(hourly_df.index))
+        print(min(hourly_df.index))
+        hourly_df = hourly_df[hourly_df.index >= self.starting_date]
+        hourly_df = hourly_df[hourly_df.index <= self.running_date]
+        print('time range after filtering ')
+        print(max(hourly_df.index))
+        print(min(hourly_df.index))
+
         hourly_df = roll_wrapper(hourly_df, lookback_window, skipping_size,
                                   lambda x: signal_generation_method_to_call(data=x, **idios), trigger)
 
